@@ -20,7 +20,7 @@ def collect_bins(bin_width,bin_precision):
 	
 	for fraction in os.listdir(file_dir):
 		for file in os.listdir(file_dir+'/'+fraction):
-			print(file,fraction)
+			print('step_3:',file,fraction)
 			file_path=file_dir+'/'+fraction+'/'+file
 			sample=file.split('.csv')[0]
 			if len(bin_df)==0:
