@@ -171,11 +171,12 @@ def pre_step(file_dir,sample_file):
 		file_fraction_dics[raw_name] = fraction_name
 	result_dir='pre_result'
 	for raw_file in os.listdir(file_dir):
-		file=open(raw_file,'r')
+		print('step_1:',raw_file)
+		file=open(file_dir+'/'+raw_file,'r')
 		oneline=file.readline()
 		oneline=file.readline()
 		file_begin=oneline.split('\t')[0]
 		sample=file_class_dics[file_begin]
 		fraction=file_fraction_dics[file_begin]
 		file.close()
-		sample_pretreat(raw_file,sample,fraction,result_dir,file_class_dics,file_fraction_dics)
+		sample_pretreat(file_dir+'/'+raw_file,sample,fraction,result_dir,file_class_dics,file_fraction_dics)
